Method: Resque::Status.counter_key
- Defined in:
- lib/resque_ui/overrides/resque_status/status.rb
.counter_key(counter, uuid) ⇒ Object
If multiple workers are running at once and you need an incrementer, you can’t use the status’ num attribute because of race conditions. You can use a counter and call incr on it instead
41 42 43 |
# File 'lib/resque_ui/overrides/resque_status/status.rb', line 41 def self.counter_key(counter, uuid) "#{counter}:#{uuid}" end |